@@ -1,5 +1,6 @@
 ###
 # Copyright (c) 2005, Jeremiah Fincher
+# Copyright (c) 2019, James Lu <james@overdrivenetworks.com>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -62,7 +63,7 @@ class Plugin(callbacks.Plugin):
         """<command>
 
         Returns the name of the plugin that would be used to call <command>.
-        
+
         If it is not uniquely determined, returns list of all plugins that
         contain <command>.
         """
@@ -151,6 +152,7 @@ class Plugin(callbacks.Plugin):
             in the format 'First Last (nick)'.
             """
             return '%(name)s (%(nick)s)' % authorInfo.__dict__
+
         def buildContributorsString(longList):
             """
             Take a list of long names and turn it into :
@@ -158,97 +160,56 @@ class Plugin(callbacks.Plugin):
             """
             L = [getShortName(n) for n in longList]
             return format('%L', L)
-        def sortAuthors():
-            """
-            Sort the list of 'long names' based on the number of contributions
-            associated with each.
-            """
-            L = list(module.__contributors__.items())
-            def negativeSecondElement(x):
-                return -len(x[1])
-            utils.sortBy(negativeSecondElement, L)
-            return [t[0] for t in L]
+
         def buildPeopleString(module):
             """
             Build the list of author + contributors (if any) for the requested
             plugin.
             """
-            head = _('The %s plugin') % cb.name()
-            author = _('has not been claimed by an author')
-            conjunction = _('and')
-            contrib = _('has no contributors listed.')
-            hasAuthor = False
-            hasContribs = False
-            if hasattr(module, '__author__'):
-                if module.__author__ != supybot.authors.unknown:
-                    author = _('was written by %s') % \
-                        utils.web.mungeEmail(str(module.__author__))
-                    hasAuthor = True
-            if hasattr(module, '__contributors__'):
-                contribs = sortAuthors()
-                if hasAuthor:
-                    try:
-                        contribs.remove(module.__author__)
-                    except ValueError:
-                        pass
-                if contribs:
-                    contrib = format(_('%s %h contributed to it.'),
-                                     buildContributorsString(contribs),
-                                     len(contribs))
-                    hasContribs = True
-                elif hasAuthor:
-                    contrib = _('has no additional contributors listed.')
-            if hasContribs and not hasAuthor:
-                conjunction = _('but')
-            return ' '.join([head, author, conjunction, contrib])
+            author = getattr(module, '__author__', supybot.authors.unknown)
+            if author != supybot.authors.unknown:
+                s = _('The %s plugin was written by %s. ' % (cb.name(), author))
+            else:
+                s = _('The %s plugin has not been claimed by an author. ') % cb.name()
+
+            contribs = getattr(module, '__contributors__', {})
+            if contribs:
+                s += format(_('%s %h contributed to it.'),
+                              buildContributorsString(contribs.keys()),
+                              len(contribs))
+            else:
+                s += _('No additional contributors are listed.')
+            return s
+
         def buildPersonString(module):
             """
             Build the list of contributions (if any) for the requested person
-            for the requested plugin
+            for the requested plugin.
             """
-            isAuthor = False
-            authorInfo = None
-            moduleContribs = module.__contributors__.keys()
+            contributors = getattr(module, '__contributors__', {})
+            # Make a mapping of nicks to author instances
+            contributorNicks = dict((author.nick.lower(), author) for author in contributors.keys())
             lnick = nick.lower()
-            for contrib in moduleContribs:
-                if contrib.nick.lower() == lnick:
-                    authorInfo = contrib
-                    break
-            authorInfo = authorInfo or getattr(supybot.authors, nick, None)
-            if not authorInfo:
-                return _('The nick specified (%s) is not a registered '
-                       'contributor.') % nick
-            fullName = utils.web.mungeEmail(str(authorInfo))
-            contributions = []
-            if hasattr(module, '__contributors__'):
-                if authorInfo not in module.__contributors__:
-                    return _('The %s plugin does not have \'%s\' listed as a '
-                           'contributor.') % (cb.name(), nick)
-                contributions = module.__contributors__[authorInfo]
-            isAuthor = getattr(module, '__author__', False) == authorInfo
-            (nonCommands, commands) = utils.iter.partition(lambda s: ' ' in s,
-                                                           contributions)
-            results = []
-            if commands:
-                s = _('command')
-                if len(commands) > 1:
-                    s = utils.str.pluralize(s)
-                results.append(format(_('the %L %s'), commands, s))
-            if nonCommands:
-                results.append(format(_('the %L'), nonCommands))
-            if results and isAuthor:
-                return format(
-                        _('%s wrote the %s plugin and also contributed %L.'),
-                        (fullName, cb.name(), results))
-            elif results and not isAuthor:
-                return format(_('%s contributed %L to the %s plugin.'),
-                              fullName, results, cb.name())
-            elif isAuthor and not results:
-                return _('%s wrote the %s plugin') % (fullName, cb.name())
-            # XXX Does this ever actually get reached?
+
+            author = getattr(module, '__author__', supybot.authors.unknown)
+            if author != supybot.authors.unknown and lnick == author.nick.lower():
+                # Special case for the plugin author. We remove legacy handling of the case where
+                # someone is listed both as author and contributor, which should never really happen?
+                return _('%s wrote the %s plugin.') % (author, cb.name())
+            elif lnick not in contributorNicks:
+                return _('%s is not listed as a contributor to %s.') % (nick, cb.name())
+
+            authorInfo = contributorNicks[lnick]
+            contributions = contributors[authorInfo]
+            fullName = getShortName(authorInfo)
+
+            if contributions:
+                return format(_('%s contributed the following to %s: %s'),
+                              fullName, cb.name(), ', '.join(contributions))
             else:
-                return _('%s has no listed contributions for the %s '
+                return _('%s did not list any specific contributions to the %s '
                          'plugin.') % (fullName, cb.name())
+
         # First we need to check and see if the requested plugin is loaded
         module = cb.classModule
         if not nick:
